==> open-xchange-core_6.22.1.orig.tar.bz2: com/hazelcast/cluster/SyncProcess.java <==
/*
 * Copyright (c) 2008-2012, Hazel Bilisim Ltd. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.cluster;

import com.hazelcast.impl.Node;
import com.hazelcast.nio.Connection;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

public class SyncProcess extends AbstractRemotelyCallable<Boolean> {

    private Connection connection;

    public Connection getConnection() {
        return connection;
    }

    public void setConnection(Connection conn) {
        this.connection = conn;
    }

    public void readData(DataInput in) throws IOException {
    }

    public void writeData(DataOutput out) throws IOException {
    }

    public Boolean call() {
        process();
        return Boolean.TRUE;
    }

    public void process() {
        Node node = getNode();
        node.concurrentMapManager.syncForAdd();
        node.listenerManager.syncForAdd();
        node.topicManager.syncForAdd();
        node.clusterManager.joinReset();
    }
}

==> open-xchange-core_7.0.1.orig.tar.bz2: com/hazelcast/cluster/SyncProcess.java <==
/*
 * Copyright (c) 2008-2012, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.cluster;

import com.hazelcast.impl.Node;
import com.hazelcast.nio.Connection;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

public class SyncProcess extends AbstractRemotelyCallable<Boolean> implements RemotelyProcessable {

    private Connection connection;

    public Connection getConnection() {
        return connection;
    }

    public void setConnection(Connection conn) {
        this.connection = conn;
    }

    public void readData(DataInput in) throws IOException {
    }

    public void writeData(DataOutput out) throws IOException {
    }

    public Boolean call() {
        process();
        return Boolean.TRUE;
    }

    public void process() {
        Node node = getNode();
        node.concurrentMapManager.syncForAdd();
        node.listenerManager.syncForAdd();
        node.topicManager.syncForAdd();
        node.clusterManager.joinReset();
    }
}
